package com.cloudhopper.jni;

/*
 * #%L
 * ch-jni-loader
 * %%
 * Copyright (C) 2012 - 2013 Cloudhopper by Twitter
 * %%
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * #L%
 */

/**
 * Debugging facilities. Set property 'java.library.debug' to 1, true, or yes to 
 * have debug information logged to stdout.
 *
 * @author garth
 */
public class Debug {
    private static boolean debug = false;

    static {
        String s = System.getProperty("java.library.debug");
        if(s != null) {
	    s = s.toLowerCase();
	    debug = (s.startsWith("y") || s.startsWith("1") || s.startsWith("true"));
	}
    }

    private String prefix() {
	return new StringBuffer().append(this.getClass().getName()).append(" [DEBUG - ").append(Thread.currentThread().getName()).append("] ").toString();
    }

    protected void debug(String s) {
	if (debug) {
	    System.out.print(prefix());
	    System.out.println(s);
	}
    }

    protected void debug(Throwable t) {
	if (debug) {
	    System.out.print(prefix());
	    t.printStackTrace(System.out);
	}
    }

    protected void debug(String s, Throwable t) {
	debug(s);
	debug(t);
    }
}
